energy_budget
-------------

.. inheritance-diagram:: climlab.process.energy_budget
   :parts: 1
   :private-bases:

.. automodule:: climlab.process.energy_budget
    :members:
    :undoc-members:
    :show-inheritance: